summaryrefslogtreecommitdiff
path: root/src/bank-lib/test_bank_interpreter.h
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2016-05-04 05:38:29 +0200
committerChristian Grothoff <christian@grothoff.org>2016-05-04 05:38:29 +0200
commit910e01d1c154390a7e724703bdd9a14046245d2c (patch)
tree284b797d8cea35efb8ba8c320057a310171d63dd /src/bank-lib/test_bank_interpreter.h
parent2c832199b2e20db5f98161b7bb6b06d94c74268f (diff)
downloadexchange-910e01d1c154390a7e724703bdd9a14046245d2c.tar.gz
exchange-910e01d1c154390a7e724703bdd9a14046245d2c.tar.bz2
exchange-910e01d1c154390a7e724703bdd9a14046245d2c.zip
be more careful with terminology
Diffstat (limited to 'src/bank-lib/test_bank_interpreter.h')
-rw-r--r--src/bank-lib/test_bank_interpreter.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/bank-lib/test_bank_interpreter.h b/src/bank-lib/test_bank_interpreter.h
index 329b51461..7f56caf4d 100644
--- a/src/bank-lib/test_bank_interpreter.h
+++ b/src/bank-lib/test_bank_interpreter.h
@@ -45,14 +45,14 @@ enum TBI_OpCode
TBI_OC_ADMIN_ADD_INCOMING,
/**
* Expect that we have received the specified transaction at fakebank.
*/
- TBI_OC_EXPECT_TRANSACTION,
+ TBI_OC_EXPECT_TRANSFER,
/**
* Expect that we have exhaustively gone over all transactions at fakebank.
*/
- TBI_OC_EXPECT_TRANSACTIONS_EMPTY
+ TBI_OC_EXPECT_TRANSFERS_EMPTY
};
@@ -118,8 +118,8 @@ struct TBI_Command
} admin_add_incoming;
/**
* If @e opcode is #TBI_OC_EXPECT_TRANSACTION, this
* specifies which transaction we expected.
*/
struct {
@@ -129,7 +129,7 @@ struct TBI_Command
*/
const char *cmd_ref;
- } expect_transaction;
+ } expect_transfer;
} details;
@@ -45,14 +45,14 @@ enum TBI_OpCode
TBI_OC_ADMIN_ADD_INCOMING,
/**
- * Expect that we have received the specified transaction at fakebank.
+ * Expect that we have received the specified transfer at fakebank.
*/
@@ -45,14 +45,14 @@ enum TBI_OpCode
/**
- * Expect that we have exhaustively gone over all transactions at fakebank.
+ * Expect that we have exhaustively gone over all transfers at fakebank.
*/
@@ -118,8 +118,8 @@ struct TBI_Command
} admin_add_incoming;
/**
- * If @e opcode is #TBI_OC_EXPECT_TRANSACTION, this
- * specifies which transaction we expected.
+ * If @e opcode is #TBI_OC_EXPECT_TRANSFER, this
+ * specifies which transfer we expected.
*/
struct {